@@ -55,18 +55,18 @@ void ConnectionBackend::setSuspended(bool enable)
         socket->setReadBufferSize(StandardBufferSize);
         if (socket->bytesAvailable() >= HeaderSize) {
             // there are bytes available
-            QMetaObject::invokeMethod(this, "socketReadyRead", Qt::QueuedConnection);
+            QMetaObject::invokeMethod(this, &ConnectionBackend::socketReadyRead, Qt::QueuedConnection);
         }
 
         // We read all bytes here, but we don't use readAll() because we need
         // to read at least one byte (even if there isn't any) so that the
-        // socket notifier is reenabled
+        // socket notifier is re-enabled
         QByteArray data = socket->read(socket->bytesAvailable() + 1);
         for (int i = data.size(); --i >= 0;) {
             socket->ungetChar(data[i]);
         }
         // Workaround Qt5 bug, readyRead isn't always emitted here...
-        QMetaObject::invokeMethod(this, "socketReadyRead", Qt::QueuedConnection);
+        QMetaObject::invokeMethod(this, &ConnectionBackend::socketReadyRead, Qt::QueuedConnection);
     }
 }
 
@@ -151,10 +151,11 @@ bool ConnectionBackend::waitForIncomingTask(int ms)
     QElapsedTimer timer;
     timer.start();
 
-    while (socket->state() == QLocalSocket::LocalSocketState::ConnectedState && !signalEmitted && (ms == -1 || timer.elapsed() < ms))
+    while (socket->state() == QLocalSocket::LocalSocketState::ConnectedState && !signalEmitted && (ms == -1 || timer.elapsed() < ms)) {
         if (!socket->waitForReadyRead(ms == -1 ? -1 : ms - timer.elapsed())) {
             break;
         }
+    }
 
     if (signalEmitted) {
         return true;
@@ -171,7 +172,11 @@ bool ConnectionBackend::sendCommand(int cmd, const QByteArray &data) const
     Q_ASSERT(socket);
 
     char buffer[HeaderSize + 2];
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+    sprintf(buffer, "%6llx_%2x_", data.size(), cmd);
+#else
     sprintf(buffer, "%6x_%2x_", data.size(), cmd);
+#endif
     socket->write(buffer, HeaderSize);
     socket->write(data);
 
