@@ -422,18 +422,43 @@ QString KProcessRunner::name() const
     return !m_desktopName.isEmpty() ? m_desktopName : m_executable;
 }
 
+// Only alphanum, ':' and '_' allowed in systemd unit names
+QString KProcessRunner::escapeUnitName(const QString &input)
+{
+    QString res;
+    const QByteArray bytes = input.toUtf8();
+    for (const auto &c : bytes) {
+        if ((c >= 'A' && c <= 'Z') || (c >= 'a' && c <= 'z') || (c >= '0' && c <= '9') || c == ':' || c == '_' || c == '.') {
+            res += QLatin1Char(c);
+        } else {
+            res += QStringLiteral("\\x%1").arg(c, 2, 16, QLatin1Char('0'));
+        }
+    }
+    return res;
+}
+
+QString KProcessRunner::maybeAliasedName(const QString &pattern) const
+{
+    // Don't actually load aliased desktop file to avoid having to deal with recursion
+    QString servName = m_service ? m_service->aliasFor() : QString{};
+    if (servName.isEmpty()) {
+        servName = name();
+    }
+
+    // As specified in "XDG standardization for applications" in https://systemd.io/DESKTOP_ENVIRONMENTS/
+    return pattern.arg(escapeUnitName(servName), QUuid::createUuid().toString(QUuid::Id128));
+}
+
 void KProcessRunner::emitDelayedError(const QString &errorMsg)
 {
     qCWarning(KIO_GUI) << errorMsg;
     terminateStartupNotification();
     // Use delayed invocation so the caller has time to connect to the signal
-    QMetaObject::invokeMethod(
-        this,
-        [this, errorMsg]() {
-            Q_EMIT error(errorMsg);
-            deleteLater();
-        },
-        Qt::QueuedConnection);
+    auto func = [this, errorMsg]() {
+        Q_EMIT error(errorMsg);
+        deleteLater();
+    };
+    QMetaObject::invokeMethod(this, func, Qt::QueuedConnection);
 }
 
 void ForkingProcessRunner::slotProcessExited(int exitCode, QProcess::ExitStatus exitStatus)
