@@ -1,31 +1,20 @@
-/* This file is part of the KDE libraries
-    Copyright (C) 2013 Dawit Alemayehu <adawit@kde.org>
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2013 Dawit Alemayehu <adawit@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
+#include "../utils_p.h"
 #include "clipboardupdater_p.h"
-#include "jobclasses.h"
 #include "copyjob.h"
 #include "deletejob.h"
-#include <kurlmimedata.h>
+#include "jobclasses.h"
+#include <KUrlMimeData>
 
+#include <QClipboard>
 #include <QGuiApplication>
 #include <QMimeData>
-#include <QClipboard>
 
 using namespace KIO;
 
@@ -41,9 +30,11 @@ static void overwriteUrlsInClipboard(KJob *job)
     QList<QUrl> newUrls;
 
     if (copyJob) {
-        Q_FOREACH (const QUrl &url, copyJob->srcUrls()) {
+        const auto srcUrls = copyJob->srcUrls();
+        newUrls.reserve(srcUrls.size());
+        for (const QUrl &url : srcUrls) {
             QUrl dUrl = copyJob->destUrl().adjusted(QUrl::StripTrailingSlash);
-            dUrl.setPath(dUrl.path() + '/' + url.fileName());
+            dUrl.setPath(Utils::concatPaths(dUrl.path(), url.fileName()));
             newUrls.append(dUrl);
         }
     } else if (fileCopyJob) {
@@ -74,11 +65,12 @@ static void updateUrlsInClipboard(KJob *job)
     bool update = false;
 
     if (copyJob) {
-        Q_FOREACH (const QUrl &url, copyJob->srcUrls()) {
+        const QList<QUrl> urls = copyJob->srcUrls();
+        for (const QUrl &url : urls) {
             const int index = clipboardUrls.indexOf(url);
             if (index > -1) {
                 QUrl dUrl = copyJob->destUrl().adjusted(QUrl::StripTrailingSlash);
-                dUrl.setPath(dUrl.path() + '/' + url.fileName());
+                dUrl.setPath(Utils::concatPaths(dUrl.path(), url.fileName()));
                 clipboardUrls.replace(index, dUrl);
                 update = true;
             }
@@ -127,7 +119,7 @@ static void removeUrlsFromClipboard(KJob *job)
     QList<QUrl> clipboardUrls = KUrlMimeData::urlsFromMimeData(mimeData);
     quint32 removedCount = 0;
 
-    Q_FOREACH (const QUrl &url, deletedUrls) {
+    for (const QUrl &url : std::as_const(deletedUrls)) {
         removedCount += clipboardUrls.removeAll(url);
     }
 
@@ -181,9 +173,9 @@ void ClipboardUpdater::update(const QUrl &srcUrl, const QUrl &destUrl)
 }
 
 ClipboardUpdater::ClipboardUpdater(Job *job, JobUiDelegateExtension::ClipboardUpdaterMode mode)
-    : QObject(job),
-      m_mode(mode)
+    : QObject(job)
+    , m_mode(mode)
 {
     Q_ASSERT(job);
-    connect(job, SIGNAL(result(KJob*)), this, SLOT(slotResult(KJob*)));
+    connect(job, &KJob::result, this, &ClipboardUpdater::slotResult);
 }
